@@ -442,7 +442,8 @@ def parse_rank(p: Product, selector: parsel.Selector = None):
 
 
 def parse_thumbnail(p: Product, selector: parsel.Selector = None):
-    thumbnail = selector.xpath("//div[@id='altImages']//img/@src").re(r"https://m\.media-amazon\.com.+")
+    thumbnail = selector.xpath("//div[@id='altImages']//img/@src").getall()
+    thumbnail = thumbnail or selector.xpath("//div[@id='imageBlockThumbs']//img/@src").getall()
     if len(thumbnail) < 1:
         p.thumbnail = None
     else:
